# ETLT-MySQL

ETLT extension for MariaDB and MySQL databases

<table>
    <thead>
        <tr>
            <th>Social</th>
            <th>Release</th>
            <th>Test</th>
            <th>Code</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>
                <a href="https://gitter.im/SetBased/py-etlt-mysql?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge">
                    <img src="https://badges.gitter.im/SetBased/py-etlt-mysql.svg" alt="Gitter"/>
                </a>
            </td>
            <td>
                <a href="https://badge.fury.io/py/ETLT-MySQL">
                    <img src="https://badge.fury.io/py/ETLT-MySQL.svg" alt="Latest Stable Version"/>
                </a>
            </td>
            <td>
                <a href="https://github.com/PyETLT/etlt-mysql/actions/workflows/unit.yml">
                    <img src="https://github.com/PyETLT/etlt-mysql/actions/workflows/unit.yml/badge.svg" alt="Unit tests"/>
                </a>
            </td>
            <td>
                <a href="https://scrutinizer-ci.com/g/PyETLT/etlt-mysql/?branch=master">
                    <img src="https://scrutinizer-ci.com/g/PyETLT/etlt-mysql/badges/quality-score.png?b=master" alt="Scrutinizer Code Quality"/>
                </a>
            </td>
        </tr>
    </tbody>
</table>

## License

This project is licensed under the terms of the MIT license.
